Security Policy
===============

Reporting a vulnerability
-------------------------

Please report any security vulnerability to tomasz@knapik.net. I appreciate if you
report this first privately before creating a public issue.
